@@ -7,7 +7,7 @@ test -z "$srcdir" && srcdir=.
 PKG_NAME="mate-dialogs"
 REQUIRED_AUTOMAKE_VERSION=1.9
 
-(test -f $srcdir/configure.in) || {
+(test -f $srcdir/configure.ac) || {
     echo -n "**Error**: Directory "\`$srcdir\'" does not look like the"
     echo " top-level matedialog directory"
     exit 1
